from django.contrib import admin

from .models import Flow, FlowNode, FlowAction, FlowNodeToAction, FlowActionToOperator, FlowNodeActionRule, FlowRecord, FlowApply


class FlowAdmin(admin.ModelAdmin):
    list_display = ('id', 'flow_name', 'module_name', 'description')
    fields = ('id', 'flow_name', 'module_name', 'description')
    search_fields = ('id', 'flow_name', 'module_name')
    readonly_fields = ['id']
    list_per_page = 20


class FlowToCategoryAdmin(admin.ModelAdmin):
    list_display = ('id', 'flow', 'category_id',)
    fields = ('id', 'flow', 'category_id',)
    search_fields = ('id', 'flow', 'category_id',)
    readonly_fields = ['id']
    list_per_page = 20


class FlowNodeAdmin(admin.ModelAdmin):
    list_display = ('id', 'flow_id', 'node_name', 'node_value', 'module_name', 'flow_number', 'status_code', 'summary', 'description', 'config', 'is_open_verify')
    fields = ('id', 'flow_id', 'node_name', 'module_name', 'node_value', 'flow_number', 'status_code', 'summary', 'description', "config", 'is_open_verify')
    search_fields = ('id', 'flow_id', 'node_name', 'module_name', 'summary')
    readonly_fields = ['id']
    ordering = ['flow_id', "flow_number"]
    list_per_page = 20


class FlowActionAdmin(admin.ModelAdmin):
    list_display = ('id', 'action', 'name', 'description', 'config')
    fields = ('id', 'action', 'name', 'description', 'config')
    search_fields = ('id', 'action', 'name', 'description', 'config')
    readonly_fields = ['id']
    ordering = ['action']
    list_per_page = 20


class FlowNodeToActionAdmin(admin.ModelAdmin):
    list_display = (
        'id', 'flow_id', 'flow_node', 'flow_action', 'flow_to_node', "flow_to_fail_node", "ttl", 'role_list',
        'user_list', "is_automatic", "description", "is_using", "relate_data_key", "api"
    )
    fields = (
        'id', 'flow_id', 'flow_node', 'flow_action', 'flow_to_node', "flow_to_fail_node", "ttl", 'role_list',
        'user_list', "is_automatic", "description", "is_using", "relate_data_key", "api"
    )
    search_fields = ('id', 'flow_node__value', 'flow_action__action')
    readonly_fields = ['id', 'flow_id']
    ordering = ['flow_node__flow_id', 'flow_node__flow_number', 'flow_to_node']
    list_filter = ['flow_node__flow_id']

    def flow_id(self, item):
        return item.flow_node.flow_id

    flow_id.short_description = '流程ID'
    list_per_page = 20


class FlowActionToOperatorAdmin(admin.ModelAdmin):
    list_display = ('id', 'flow_action_id', 'role_id', 'user_id')
    fields = ('id', 'flow_action_id', 'role_id', 'user_id')
    search_fields = ('id', 'flow_action_id', 'role_id', 'user_id')
    readonly_fields = ['id']
    list_per_page = 20


class FlowNodeActionRuleAdmin(admin.ModelAdmin):
    list_display = (
        "id", "flow_node_to_action", "rule_name", "rule_sort", "inflow_service", "inflow_module", "inflow_field", "outflow_module",
        "outflow_field", "default_value", "expression_string", "python_script", "is_using", "run_mode"
    )
    fields = (
        "id", "flow_node_to_action", "rule_name", "rule_sort", "inflow_service", "inflow_module", "inflow_field", "outflow_module",
        "outflow_field", "default_value", "expression_string", "python_script", "is_using", "run_mode"
    )
    search_fields = ('id', 'rule_name')
    readonly_fields = ['id']
    list_per_page = 20


class FlowRecordAdmin(admin.ModelAdmin):
    list_display = (
        "id", "user_id", "belong_role_id", "flow_node", "flow_action", "relate_data_key", "relate_data_value", "request_params", "process_context", "create_time"
    )
    fields = (
        "id", "user_id", "belong_role_id", "flow_node", "flow_action", "relate_data_key", "relate_data_value", "request_params", "process_context", "create_time"
    )
    search_fields = ('id', 'flow_node_id')
    readonly_fields = ['id', "create_time"]
    list_per_page = 20


class FlowApplyAdmin(admin.ModelAdmin):
    list_display = (
        "id", "apply_user_id", "apply_flow_node", "verify_user_id", "verify_role_id", "copy_to_users", "relate_data_key",
        "relate_data_value", "is_verified", "reply", "create_time", "update_time",
    )
    fields = (
        "id", "apply_user_id", "apply_flow_node", "verify_user_id", "verify_role_id", "copy_to_users", "relate_data_key",
        "relate_data_value", "is_verified", "reply", "create_time", "update_time",
    )
    search_fields = ('id', 'flow_node')
    readonly_fields = ['id', "create_time", "update_time"]
    list_per_page = 20


admin.site.register(Flow, FlowAdmin)
admin.site.register(FlowNode, FlowNodeAdmin)
admin.site.register(FlowAction, FlowActionAdmin)
admin.site.register(FlowNodeToAction, FlowNodeToActionAdmin)
admin.site.register(FlowActionToOperator, FlowActionToOperatorAdmin)
admin.site.register(FlowNodeActionRule, FlowNodeActionRuleAdmin)
admin.site.register(FlowRecord, FlowRecordAdmin)
admin.site.register(FlowApply, FlowApplyAdmin)



# -*- encoding:utf-8 -*-
import os
import xlsxwriter

from main.settings import STATICFILES_DIRS


class ExcelOperate:
    # 将数据导出为Excel
    @staticmethod
    def write_data_to_excel(save_dir, filename, format, header_list, data_list):
        '''
        瑛式备注
        :param save_dir: 保存文件的目录
        :param filename: 生成文件的文件名
        :param format: 生成文件的文件格式，只能是xlsx,xls,csv
        :param header_list: 文件的表头，即第一行标题
        :return:
        '''

        folder_name = os.path.join(STATICFILES_DIRS[0], save_dir)
        # 没有该目录，则创建
        Jt.make_dir(folder_name=folder_name)

        save_path = os.path.join(STATICFILES_DIRS[0], save_dir + filename + '.' + format)

        # 打开文件
        wb = xlsxwriter.Workbook(save_path)

        # 添加名字为Sheet1的Sheet
        ws = wb.add_worksheet('Sheet1')

        # 设置表头
        row_num = 0
        columns = header_list
        for col_num in range(len(columns)):
            # 表头写入第一行
            ws.write(row_num, col_num, columns[col_num])

        for index, it in enumerate(data_list):
            ws.write(index + 1, 0, it[0])  # A2 写入第A列数据
            ws.write(index + 1, 1, it[1])  # B2 写入第B列数据
            ws.write(index + 1, 2, it[2])  # C2 写入第C列数据
            ws.write(index + 1, 3, it[3])  # D2 写入第D列数据
            ws.write(index + 1, 4, it[4])  # E2 写入第E列数据
            ws.write(index + 1, 5, it[5])  # F2 写入第F列数据
            ws.write(index + 1, 6, it[6])  # G2 写入第G列数据
            ws.write(index + 1, 7, it[7])  # H2 写入第H列数据
            ws.write(index + 1, 8, it[8])  # I2 写入第I列数据
        wb.close()

        return 1










# encoding: utf-8
"""
@project: djangoModel->setup
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis: 模块打包文件
@created_time: 2022/6/18 15:14
"""
from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf8') as fp:
    log_desc = fp.read()

setup(
    name='xj_flow',  # 模块名称
    version='1.0.19',  # 模块版本
    description='流程模块',  # 项目 摘要描述
    long_description=log_desc,  # 项目描述
    long_description_content_type="text/markdown",  # md文件，markdown格式
    author='赵向明',  # 作者
    author_email='sieyoo@163.com',  # 作者邮箱
    maintainer="孙楷炎",  # 维护者
    maintainer_email="sky4834@163.com",  # 维护者的邮箱地址
    packages=find_packages(),  # 系统自动从当前目录开始找包
    license="apache 3.0",
    install_requires=[]
)
